@@ -26,7 +26,7 @@ use constant VALIDATE_HOSTNAME => eval 'require Data::Validate::Domain;1';
 use constant VALIDATE_IP       => eval 'require Data::Validate::IP;1';
 
 our $ERR;    # ugly hack to improve validation errors
-our $VERSION = '2.15';
+our $VERSION = '2.16';
 our @EXPORT_OK = qw(joi validate_json);
 
 my $BUNDLED_CACHE_DIR = path(path(__FILE__)->dirname, qw(Validator cache));
@@ -948,7 +948,11 @@ sub _is_date_time {
   @time = map { s/^0//; $_ } reverse @time[0 .. 5];
   $time[4] -= 1;    # month are zero based
   local $@;
-  return eval { Time::Local::timegm(@time); 1 } || 0;
+  return 1 if eval { Time::Local::timegm(@time); 1 };
+  $JSON::Validator::ERR = (split / at /, $@)[0];
+  $JSON::Validator::ERR =~ s!('-?\d+'\s|\s[\d\.]+)!!g;
+  $JSON::Validator::ERR .= '.';
+  return 0;
 }
 
 sub _is_domain { warn "Data::Validate::Domain is not installed"; return; }
@@ -1050,7 +1054,7 @@ JSON::Validator - Validate data against a JSON schema
 
 =head1 VERSION
 
-2.15
+2.16
 
 =head1 SYNOPSIS
 
